===================================
MOKKa
===================================

Welcome to the documentation of the MOKKa package.
This package aims to collect useful building blocks for physical layer simulations of communication systems implemented in various machine learning frameworks.


.. toctree::
   :maxdepth: 2
   :caption: Contents

   api/mokka

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
